==> haskell-hls-code-range-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-code-range-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-code-range-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-code-range-plugin-2.1.0.0-6D2ShTk3QhF5WxUEmkKmfD
key:                  hls-code-range-plugin-2.1.0.0-6D2ShTk3QhF5WxUEmkKmfD
license:              Apache-2.0
maintainer:           kokobd
author:               kokobd
synopsis:
    HLS Plugin to support smart selection range and Folding range

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  3c93a17bb0ff8ba834da98bba58d8015
exposed:              True
exposed-modules:      Ide.Plugin.CodeRange Ide.Plugin.CodeRange.Rules
hidden-modules:       Ide.Plugin.CodeRange.ASTPreProcess
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-code-range-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-code-range-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-code-range-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-code-range-plugin
hs-libraries:         HShls-code-range-plugin-2.1.0.0-6D2ShTk3QhF5WxUEmkKmfD
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 extra-1.7.16-3o8MjPiNQTlLg74BSenHLy
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX mtl-2.3.1
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9 text-2.0.2
    transformers-0.6.1.0 vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-hls-code-range-plugin/html/hls-code-range-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-code-range-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-code-range-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-code-range-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-code-range-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-code-range-plugin-2.1.0.0-7ox76uc4XlN1TB1v0i1byv
key:                  hls-code-range-plugin-2.1.0.0-7ox76uc4XlN1TB1v0i1byv
license:              Apache-2.0
maintainer:           kokobd
author:               kokobd
synopsis:
    HLS Plugin to support smart selection range and Folding range

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e391ceb2b5217540820c1448580c9342
exposed:              True
exposed-modules:      Ide.Plugin.CodeRange Ide.Plugin.CodeRange.Rules
hidden-modules:       Ide.Plugin.CodeRange.ASTPreProcess
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-code-range-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-code-range-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-code-range-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-code-range-plugin
hs-libraries:         HShls-code-range-plugin-2.1.0.0-7ox76uc4XlN1TB1v0i1byv
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 extra-1.7.16-IkudFHstV64EKMSGT8IWWb
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    mtl-2.3.1 semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS text-2.0.2
    transformers-0.6.1.0 vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-hls-code-range-plugin/html/hls-code-range-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-code-range-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
